@@ -166,4 +166,8 @@ def precisionStr(x, delt):
         s = s[0] + '.' + s[1:]
     if s[-1] == '.':
         s = s[:-1]
-    return sig+s
\ No newline at end of file
+    return sig+s
+    
+
+def ValueStr(val, uncertain):
+    return precisionStr(val, uncertain) + ' \pm  ' + str(roundUp(uncertain))
\ No newline at end of file
