@@ -112,7 +112,7 @@ class table:
             if not ef.isUncertain(*self.data.columns[0:2]):
                 self.data.insert(1, ef.delt(
                     self.data.columns[0]), [0 for i in range(len(self.data))])
-            
+
             while lol:
                 lol = False
                 for i in range(1, len(self.data.columns) - 1):
@@ -413,9 +413,6 @@ class table:
                         **kwargs)
         ax.set_xlabel(ef.ax_name(dt, xn))
         ax.set_ylabel(ef.ax_name(dt, yn))
-        # plt.legend(
-        
-
 
     def fit(self, func, xn, yn, fig_ax=None, show=True, p0=None, maxfev=1000,
             fit_label='fit', fit_color=None, **kwargs):
@@ -450,9 +447,6 @@ class table:
         dt.renameCols(noms[1:])
         lines = inspect.getsourcelines(func)
 
-        polar = False
-        if 'polar' in kwargs:
-            polar = kwargs['polar']
         if len(lines) == 2 and fit_label == 'fit':
             expr = sp.sympify(ef.preSymp(lines[0][-1].replace('return ', '')))
             fit_label = "$"+sp.latex(expr)+"$"
