@@ -7,29 +7,30 @@ prefixs = {"y": 1e-24, "z": 1e-21, "a": 1e-18, "f": 1e-15, "p": 1e-12,
            "P": 1e15, "B": 1e15, "E": 1e18, "Z": 1e21, "Y": 1e24}
 SI = sp.symbols("g s m K A mol cd")
 
-SIBT = {'Hz':     '1/s',
-        'newton': '1000*g*(m/s**2)',
-        'Pa':     '1000*g/m/s**2',
-        'J':      '1000*g*m**2/s**2',
-        'W':      '1000*g*m**2/s**3',
-        'C':      's*A',
-        'V':      '1000*g*m**2/s**3/A',
-        'F':      'A**2*s**4/(1000*g)/m**2',
-        'ohms':   '1000*g*m**2/s**3/A**2',
-        'S':      'A**2/(1000*g)/m**2*s**3',
-        'H':      'm**2*(1000*g)/s**2/A**2',
-        '\AA':    '0.0000000001*m',
-        'Wb':     '1000*m**2*g/s**2/A',
-        'T':      '1000*g/A/s**2',
-        'lm':     'cd',
-        'lx':     'cd/m**2',
-        'Bq':     '1/s',
-        'Gy':     'm**2/s**2',
-        'G':      '0.1*g/(A*s**2)',
-        'lb':     '453.59237*g',
-        'oz':     '28.3495231*g',
-        'L':      'm**3',
-        'percent':'0.01'
+SIBT = {'Hz':       '1/s',
+        'newton':   '1000*g*(m/s**2)',
+        'Pa':       '1000*g/m/s**2',
+        'J':        '1000*g*m**2/s**2',
+        'W':        '1000*g*m**2/s**3',
+        'C':        's*A',
+        'V':        '1000*g*m**2/s**3/A',
+        'F':        'A**2*s**4/(1000*g)/m**2',
+        'ohms':     '1000*g*m**2/s**3/A**2',
+        'S':        'A**2/(1000*g)/m**2*s**3',
+        'H':        'm**2*(1000*g)/s**2/A**2',
+       r'\AA':      '0.0000000001*m',
+        'Wb':       '1000*m**2*g/s**2/A',
+        'T':        '1000*g/A/s**2',
+        'lm':       'cd',
+        'lx':       'cd/m**2',
+        'Bq':       '1/s',
+        'Gy':       'm**2/s**2',
+        'G':        '0.1*g/(A*s**2)',
+        'lb':       '453.59237*g',
+        'oz':       '28.3495231*g',
+        'L':        'm**3',
+        'percent':  '0.01',
+        'deg':      '2 * 3.1415926535/360'
        }
 SIBT = dict(zip(sp.symbols(list(SIBT.keys())), SIBT.values()))
 # SIBT = dict(zip(SIB, sp.sympify(defs)))
